#! /usr/bin/env python

## Copyright 1999-2001 by LivingLogic AG, Bayreuth, Germany.
## Copyright 1999-2001 by Walter Drwald
##
## All Rights Reserved
##
## Permission to use, copy, modify, and distribute this software and its documentation
## for any purpose and without fee is hereby granted, provided that the above copyright
## notice appears in all copies and that both that copyright notice and this permission
## notice appear in supporting documentation, and that the name of LivingLogic AG or
## the author not be used in advertising or publicity pertaining to distribution of the
## software without specific, written prior permission.
##
## LIVINGLOGIC AG AND THE AUTHOR DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
## INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
## LIVINGLOGIC AG OR THE AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
## DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
## IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR
## IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

"""
<doc:par>A module that allows you to embed JSP content as processing instructions.</doc:par>
"""

__version__ = tuple(map(int, "$Revision: 2.14 $"[11:-2].split(".")))
# $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/jsp.py,v $

from xist import xsc

class scriptlet(xsc.ProcInst):
	"""
	will be published as <markup>&lt;% data %&gt;</markup>
	"""
	def publish(self, publisher):
		publisher.publish(u"<% ")
		publisher.publish(self.content)
		publisher.publish(u" %>")

class expression(xsc.ProcInst):
	"""
	will be published as <markup>&lt;%= data %&gt;</markup>
	"""

	def publish(self, publisher):
		publisher.publish(u"<%= ")
		publisher.publish(self.content)
		publisher.publish(u" %>")

class declaration(xsc.ProcInst):
	"""
	will be published as <markup>&lt;%! data %&gt;</markup>
	"""

	def publish(self, publisher):
		publisher.publish(u"<%! ")
		publisher.publish(self.content)
		publisher.publish(u" %>")

class If(scriptlet):
	name = "if"

	def convert(self, converter):
		return scriptlet(u"if(" + self.content + u"){")

class Else(scriptlet):
	name = "else"

	def convert(self, converter):
		return scriptlet(u"}else{")

class ElIf(scriptlet):
	name = "elif"

	def convert(self, converter):
		return scriptlet(u"}else if (" + self.content + "){")

class End(scriptlet):
	name = "end"

	def convert(self, converter):
		return scriptlet(u"}")

class directive(xsc.Element):
	empty = 1
	register = 0 # only serves as a base class

	def publish(self, publisher):
		if self.publishPrefix is not None:
			publishPrefix = self.publishPrefix
		else:
			publishPrefix = publisher.publishPrefix
		publisher.publish(u"<%@ ")
		if publishPrefix:
			publisher.publish(self.prefix())
			publisher.publish(u":")
		name = self.name
		pos = name.find(".")
		if pos != -1:
			name = name[pos+1:]
		publisher.publish(name)
		self._publishAttrs(publisher)
		publisher.publish(u"%>")

class directive_include(directive):
	register = 1
	name = "directive.include"
	attrHandlers = {"file": xsc.TextAttr}

class directive_taglib(directive):
	register = 1
	name = "directive.taglib"
	attrHandlers = {"uri": xsc.TextAttr, "prefix": xsc.TextAttr}

class directive_page(directive):
	register = 1
	name = "directive.page"
	attrHandlers = {"import": xsc.TextAttr, "buffer": xsc.TextAttr, "errorPage": xsc.URLAttr, "session": xsc.TextAttr}

# register all the classes we've defined so far
namespace = xsc.Namespace("jsp", "http://java.sun.com/products/jsp/dtd/jsp_1_0.dtd", vars())
